/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2017 SEGGER Microcontroller GmbH & Co. KG         *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.32                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS RL78L12 CPU on the RSKRL78L12 board

NOTES   : The RL78L12 CPU shares the LED port pins with LCD segment
          ports.
          To use the LEDs, remove the RSK LCD APP board
          and close jumper J9

--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

#ifdef __ICCRL78__
  #include <ior5f10rlc.h>
  #include <ior5f10rlc_ext.h>
#elif defined (__GNUC__)
  #include "iodefine.h"
  #include "iodefine_ext.h"
#elif defined (__CCRL__)
  #include "iodefine.h"
#endif

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** Assign LEDs to Ports ****************************************/

#define LEDPORT_DATA  (P5)
#define LEDPORT_MODE  (PM5)
#define LED0_BIT      (1)
#define LED1_BIT      (2)
#define LED0_MASK     (1uL << LED0_BIT)
#define LED1_MASK     (1uL << LED1_BIT)
#define LED_MASK_ALL  ((LED0_MASK) | (LED1_MASK))

#define LED_MAX_INDEX (1uL)     // We enable two LEDs on the RSK board

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Disable the LCD segment outputs, switch to port mode
  //
  PFSEG1 &= ~(1u << 1);
  PFSEG1 &= ~(1u << 0);

  LEDPORT_MODE &= ~(LED_MASK_ALL);    // Switch LED-Port to output mode
  LEDPORT_DATA |=  (LED_MASK_ALL);    // Initially switch off LEDs

}

/*********************************************************************
*
*       LED switching routines
*       LEDs are switched on with low level on port lines
*/
void BSP_SetLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    LEDPORT_DATA &= ~(1uL << (Index + LED0_BIT)); /* Switch on LED */
  }
}

void BSP_ClrLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    LEDPORT_DATA |= (1uL << (Index + LED0_BIT));  /* Switch off LED  */
  }
}

void BSP_ToggleLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    if (LEDPORT_DATA & (1uL << (Index + LED0_BIT))) { /* LED is switched off */
      BSP_SetLED(Index);
    } else {
      BSP_ClrLED(Index);
    }
  }
}

/****** End Of File *************************************************/



