/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2017 SEGGER Microcontroller GmbH & Co. KG         *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 4.32                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS RL78G13 CPU on the YRPBRL78G13 promotion board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#ifdef __ICCRL78__
  #include <ior5f100LE.h>
#elif defined (__CCRL__)
  #include "iodefine.h"
#endif

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LEDPORT_DATA  (P7)
#define LEDPORT_MODE  (PM7)
#define LED0_BIT      (7)
#define LED0_MASK     (1uL << LED0_BIT)
#define LED_MASK_ALL  (LED0_MASK)

#define LED_MAX_INDEX (0uL)  // Only one user LED on the promotion board

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LEDPORT_MODE &= ~(LED_MASK_ALL);    // Switch LED-Port to output mode
  LEDPORT_DATA |=  (LED_MASK_ALL);    // Initially switch off LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    LEDPORT_DATA &= ~(1uL << (Index + LED0_BIT));  /* Switch on LED */
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    LEDPORT_DATA |= (1uL << (Index + LED0_BIT));  /* Switch off LED */
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index <= (int) LED_MAX_INDEX) {
    if (LEDPORT_DATA & (1uL << (Index + LED0_BIT))) {
      LEDPORT_DATA &= ~(1uL << (Index + LED0_BIT));  /* Switch on LED */
    } else {
      LEDPORT_DATA |= (1uL << (Index + LED0_BIT));  /* Switch off LED */
    }
  }
}

/****** End Of File *************************************************/
